<?PHP

class CObject {

	var $template_dir = "./templates";
	var $compile_dir = "./templates_c";
	var $config_dir = "./configs";
	var $tpl_prefix = ".tpl";

	/*********************
	* Constructor
	***/
	function CObject() {
			$this->smarty = new Smarty();
			$this->smarty->template_dir = $this->template_dir;
			$this->smarty->compile_dir = $this->compile_dir;
			$this->smarty->config_dir = $this->config_dir;
	}
	
	function setTemplatePath($path){
		$smarty->template_dir = $smarty_tmpl;
		$smarty->compile_dir = $smarty_tmplc;
		$smarty->config_dir = $smarty_cfg;
	}
	
	function regSmarty(&$smarty) {
		$this->smarty = $smarty;
	}

	/*************************************
	* Return the smarty object.
	***/
	function getSmarty() {
		return $this->smarty;
	}

	function setTPL($TPL) {
		$this->current_TPL = $TPL;
	}
	function getTPL() {
		return $this->current_TPL;
	}
	/**************************
	* Register any variable to this object
	* @param String variable name
	* @param variable
	* @param Boolean autoHTTP
	* @param String alias
	* @param String regular expression
	***/
	function regVar($varName, $value, $autoHTTP, $autoSQL, $alias) {
		global $err;

		$this->$varName = $value;
		$this->vars[$varName]["autoHTTP"] = $autoHTTP;
		$this->vars[$varName]["autoSQL"] = $autoSQL;

		if($autoHTTP == true || $autoSQL == true) {
			if(strpos($alias, "*") > 0) {
				$this->vars[$varName]["alias"] = str_replace("*", $varName, $alias);
			}
			else if($alias != "") {
				$this->vars[$varName]["alias"] = $alias;
			}
			else {
				$err->catch($varName, get_class($this) ."->regVar()", "if autoHTTP has been set to true, you must define an alias for it, use [% or a HTTP name]");
				// if dieOnError is true, stop program and print error to screen.
				if ($err->dieOnError == true) {
					$err->printErrors();
					die();
				}
			}
		}
	}

	/**************************
	* Register arrays with this object
	* @param String array name
	***/
	function regArray($arrName) {

		$this->$arrName = Array();
	}

	/**************************
	* Register objects
	* @param String class name
	* @param String object name
	* @param boolean HTTP check
	* @param boolean HTTP check
	***/
	function regObject($className, $objectName, $HTTPCheck, $SQLCheck) {

		$this->$objectName = new $className;
		$this->objects[$objectName]["HTTPCheck"] = $HTTPCheck;
		$this->objects[$objectName]["SQLCheck"] = $SQLCheck;
	}

	function getObject($objectName) {
		$temp = &$this->$objectName; 
		return $temp;
	}

	function setObject($objectName, &$object) {
		$this->$objectName = &$object; 
	}

	/**************************
	* Set any variable with this method
	* @param String variable name
	* @param Any value
	***/
	function setVar($var, $value) {
		global $err;

		if(!isset($this->vars[$var])) {
			$err->catch($var, $this->getParent() ."->setVar()", "no such variable defined in object ". get_class($this));
			// if dieOnError is true, stop program and print error to screen.
			if ($err->dieOnError == true) {
				$err->printErrors();
				die();
			}
		}
		else {
 			$this->$var = $value;
		}
	}
	/*********************
	* Get a set variable
	* @param String variable name
	* @return value
	***/
	function getVar($var) {
		global $err;

		if(!isset($this->vars[$var])) {
			$err->catch($var, $this->getParent() ."->getVar()", "no such variable");
			// if dieOnError is true, stop program and print error to screen.
			if ($err->dieOnError == true) {
				$err->printErrors();
				die();
			}
		}
		else {
			return $this->$var;
		}
	}

	/************************
	* Set any array with this method
	* @param array name
	* @param array
	***/
	function setArray($arr, $value) {
		global $err;

		if(!isset($this->$arr)) {
			$err->catch($arr, $this->getParent() ."->setArray()", "no such array defined in object ". get_class($this));
			// if dieOnError is true, stop program and print error to screen.
			if ($err->dieOnError == true) {
				$err->printErrors();
				die();
			}
		}
		else {
			$this->$arr = $value;
		}
	}

	/************************
	* Append array with this method
	* @param array name
	* @param array element
	* @param array index (optional)
	***/
	function appendArray() {
		global $err;

		$params 	= 	func_get_args();
		$arr 		= 	$params[0];
		$value 	= 	$params[1];
		$index 		= 	isset($params[2]) ? $params[2] : '';

		if(!isset($this->$arr)) {
			$err->catch($arr, $this->getParent() ."->appendArray()", "no such array defined in object ". get_class($this));
			// if dieOnError is true, stop program and print error to screen.
			if ($err->dieOnError == true) {
				$err->printErrors();
				die();
			}
		}
		else {
			switch(func_num_args()) {
				case 1:
					$err->catch($arr, $this->getParent() ."->appendArray()", "at least two parameters are required [array name, value, index]");
					// if dieOnError is true, stop program and print error to screen.
					if ($err->dieOnError == true) {
						$err->printErrors();
						die();
					}
				break;
				case 2:
					// only works this way..
					$tmp_array = $this->$arr;
					$tmp_array[] = $value;
					$this->$arr = $tmp_array;
				break;
				case 3:
					$this->$arr[$index] = $value;
				break;
				default:
					$err->catch($arr, $this->getParent() ."->appendArray()", "too many parameters, a maximum of three can be specified [array name, value, index]");
					// if dieOnError is true, stop program and print error to screen.
					if ($err->dieOnError == true) {
						$err->printErrors();
						die();
					}
				break;
			}
			
		}
	}
	/*********************
	* Get a set array
	* @param array name
	* @return array
	***/
	function getArray($arr) {
		global $err;

		if(!isset($this->$arr)) {
			$err->catch($arr, $this->getParent() ."->getArray()", "no such array");
			// if dieOnError is true, stop program and print error to screen.
			if ($err->dieOnError == true) {
				$err->printErrors();
				die();
			}
		}
		else {
			return $this->$arr;
		}
	}
	/*********************
	* Get all keys from an array
	* @param array name
	* @return array keys
	***/
	function getArrayKeys($arr) {
		global $err;

		if(!isset($this->$arr)) {
			$err->catch($arr, $this->getParent() ."->getArrayKeys()", "no such array");
			// if dieOnError is true, stop program and print error to screen.
			if ($err->dieOnError == true) {
				$err->printErrors();
				die();
			}
		}
		else {
			return array_keys($this->$arr);
		}
	}

	/************************************************
	* Get regular expression for a specific variable. 
	* @param String varName
	* @param regular expression
	***/
	function setRegExp($varName, $regExp) {
		global $err;

		if(!isset($this->vars[$varName])) {
			$err->catch($varName, $this->getParent() ."->setRegExp()", "no such variable");
			// if dieOnError is true, stop program and print error to screen.
			if ($err->dieOnError == true) {
				$err->printErrors();
				die();
			}
		}
		else {
			$this->vars[$varName]["regExp"] = $regExp;
		}
	}

	/************************************************
	* Get regular expression for a specific variable. 
	* @param String varName
	* @return String regular expression
	***/
	function getRegExp($varName) {
		global $err;

		if(!isset($this->vars[$varName])) {
			$err->catch($varName, $this->getParent() ."->getRegExp()", "no such variable");
			// if dieOnError is true, stop program and print error to screen.
			if ($err->dieOnError == true) {
				$err->printErrors();
				die();
			}
		}
		elseif(!isset($this->vars[$varName]["regExp"])) {
			$err->catch($varName, $this->getParent() ."->getRegExp()", "no regular expression defined for variable [$varName]");
			// if dieOnError is true, stop program and print error to screen.
			if ($err->dieOnError == true) {
				$err->printErrors();
				die();
			}
		}
		else {
			return $this->vars[$varName]["regExp"];
		}
	}

	/**********************************************
	* Define which variables are to be automatically 
	* assigned to particular templates.
	* @param String variable name
	* @param String,array template(s)
	* @param boolean autoTPL
	***/
	function setSmartyCheck($varName, $TPL, $autoTPL) {
		global $err;

		if(!isset($this->vars[$varName]) && !is_array($this->$varName)) {
			$err->catch($varName, $this->getParent() ."->setSmartyCheck()", "no such variable");
			// if dieOnError is true, stop program and print error to screen.
			if ($err->dieOnError == true) {
				$err->printErrors();
				die();
			}
		}
		else {
			if(is_array($this->$varName)) {
				// if the varName is an array fill the arr array.
				$this->arr[$varName]["TPL"] = $TPL;
				$this->arr[$varName]["autoTPL"] = $autoTPL;
			}
			else {
				// if the varName is an array fill the vars array.
				$this->vars[$varName]["TPL"] = $TPL;
				$this->vars[$varName]["autoTPL"] = $autoTPL;
			}
		}		
	}
	
	/*************************************
	* Assign variables/arrays to smarty
	* Go through all objects to see if there are any variables which need to be
	* assigned or appended to smarty.
	***/
	function assignToSmarty(&$smarty, &$current_TPL) {
		// ASSIGN TO SMARTY!!
		if(count($this->vars) > 0) {
			$keys = array_keys($this->vars);
			for($i=0; $i<count($keys); $i++) {
			    if(isset($this->vars[$keys[$i]]["TPL"])){
				$tempArr = explode(";", $this->vars[$keys[$i]]["TPL"]);
				for($x=0; $x< count($tempArr); $x++) {
					if($this->vars[$keys[$i]]["autoTPL"] == true && ($tempArr[$x] == $current_TPL || $tempArr[$x] == "_ALL_")) {
						$smarty->assign($keys[$i], $this->$keys[$i]);
					}
				}
			    }
			}
		}
		// APPEND TO SMARTY!!
		if(isset($this->arr) && is_array($this->arr) && count($this->arr) > 0) {
			$arrKeys = array_keys($this->arr);

			for($i=0; $i < count($arrKeys); $i++) {
				$tempArr = explode(";", $this->arr[$arrKeys[$i]]["TPL"]);
				for($x=0; $x< count($tempArr); $x++) {
					if($this->arr[$arrKeys[$i]]["autoTPL"] == true && ($tempArr[$x] == $current_TPL || $tempArr[$x] == "_ALL_")) {
						for($z=0; $z < count($this->$arrKeys[$i]); $z++) {
							$newArray = $this->$arrKeys[$i];
							$smarty->append($arrKeys[$i], $newArray[$z]);
						}
					}
				}
			}
		}
		// are there any more objects that have variables which need to be assigned to smarty?
		// go through all objects recursively
		if(isset($this->objects) && is_array($this->objects) && count($this->objects) > 0) {
			$objKeys = array_keys($this->objects);
			for($o=0; $o < count($this->objects); $o++) {
				$this->$objKeys[$o]->assignToSmarty($smarty, $current_TPL);
			}

		}
	}

	/******************************
	* Check variable with the regular 
	* expression specified in the set method.
	***/
	function checkVar($var) {
		global $err;

		if(!isset($this->vars[$var])) {
			$err->catch($var, $this->getParent() ."->checkVar()", "no such variable");
			// if dieOnError is true, stop program and print error to screen.
			if ($err->dieOnError == true) {
				$err->printErrors();
				die();
			}
		}
		else if($this->vars[$var]["regExp"] == "") {
			$err->catch($var, $this->getParent() ."->checkVar()", "no regular expression was found for the specified variable");
			// if dieOnError is true, stop program and print error to screen.
			if ($err->dieOnError == true) {
				$err->printErrors();
				die();
			}
		}
		else {
			if (!ereg($this->vars[$var]["regExp"], $this->$var)) {
				$this->vars[$var]["formError"] = 1;
				return 1;
			}
			else {
				$this->vars[$var]["formError"] = 0;
				return 0;
			}
		}
	}

	/**********************
	* Return all variables
	* @return array of variables
	***/
	function getAllVars() {
		return $this->vars;
	}


	function checkIn() {
		global $err;
		$params = func_get_args();
		$this->checkInType 	= 	$params[0]; // HTTP or SQL
		$array 							=	$params[1];
		if(func_num_args() == 0) {
			$err->catch($var, $this->getParent() ."->checkIn()", "you must specify one parameter for a HTTP check in and 2 parameters for an SQL check in, use [HTTP or SQL, array]");
			// if dieOnError is true, stop program and print error to screen.
			if ($err->dieOnError == true) {
				$err->printErrors();
				die();
			}
		}
		else if(!isset($this->checkInType)) {
			$err->catch($var, $this->getParent() ."->checkIn()", "you must specify a check in type, use [HTTP or SQL]");
			// if dieOnError is true, stop program and print error to screen.
			if ($err->dieOnError == true) {
				$err->printErrors();
				die();
			}
		}
		else if($this->checkInType == "SQL" && !isset($array)) {
			$err->catch($var, $this->getParent() ."->checkIn()", "if you are checking in an SQL array, you must pass the array as the second parameter");
			// if dieOnError is true, stop program and print error to screen.
			if ($err->dieOnError == true) {
				$err->printErrors();
				die();
			}
		}
		switch($this->checkInType) {
			case "HTTP" :
				$this->checkHTTP();
			break;
			case "SQL" :
				$this->checkSQL($array);
			break;
		}
	}

	function checkHTTP() {
		global $HTTP_POST_VARS;
		global $HTTP_GET_VARS;
		$HTTPArr = array_merge($HTTP_POST_VARS, $HTTP_GET_VARS);

		// distribute array to all participating sub-objects
		$this->distribute($HTTPArr, "HTTP");

		if(count($this->objects) > 0) {
			$keys = array_keys($this->objects);
			for($i=0; $i < count($keys); $i++) {
				if($this->objects[$keys[$i]]["HTTPCheck"] == true) {
					$this->$keys[$i]->checkHTTP();
				}
			}
		} 
	}

	function checkSQL($SQLArr) {
		
		// distribute array to all participating sub-objects
		$this->distribute($SQLArr, "SQL");

		if(isset($this->objects) && is_array($this->objects) && count($this->objects) > 0) {
			$keys = array_keys($this->objects);
			for($i=0; $i < count($keys); $i++) {
				if($this->objects[$keys[$i]]["SQLCheck"] == true) {
					$this->$keys[$i]->checkSQL($SQLArr);
				}
			}
		} 
	}

	/*****************************************
	* Assign all HTTP variables to respective class variables
	* @param Array HTTP_POST_VARS, HTTP_GET_VARS
	***/
	function distribute($arr, $arrType) {
		global $err;
		if(!is_array($arr)) {
			$err->catch($arr, $this->getParent() ."->assignHTTP()", "no HTTP or SQL array to assign");
			// if dieOnError is true, stop program and print error to screen.
			if ($err->dieOnError == true) {
				$err->printErrors();
				die();
			}
		}
		else if (count($this->vars) > 0 && count($arr) > 0) {
			$arrKeys = array_keys($arr);
			$objKeys = array_keys($this->vars);

			for($i=0; $i < count($objKeys); $i++) {
				if(in_array($this->vars[$objKeys[$i]]["alias"], $arrKeys) && $this->vars[$objKeys[$i]]["auto". $arrType] == true) {
					$this->$objKeys[$i] = $arr[$this->vars[$objKeys[$i]]["alias"]];
				}
			}
		}
	}
	
	/*********************************
	* Print all variables registered with this object
	***/
	function printVars() {
		global $err;
		$params = func_get_args();

		if (func_num_args() > 1) {
			for ($i=0; $i < func_num_args(); $i++) {
				$variables .= $params[$i];
				if($i != func_num_args()) {
					$variables .= ", ";
				} 
			}
			$err->catch($variables, $this->getParent() ."->printVars()", "only one paramter allowed, use one of the following [value, autoHTTP, autoSQL, alias, regExp]");
			// if dieOnError is true, stop program and print error to screen.
			if ($err->dieOnError == true) {
				$err->printErrors();
				die();
			}
		}
		else if (func_num_args() == 1) {
			$allowedTypes = array("value", "autoHTTP", "autoSQL", "alias", "regExp");
			$error = true;
			for ($i=0; $i < count($allowedTypes); $i++) {
				if($params[0] == $allowedTypes[$i]) {
						$error = false;
				}
			}				
			if ($error == true) {
				$err->catch($params[0], $this->getParent() ."->printVars()", "paramter not allowed, use one of the following [value, autoHTTP, autoSQL, alias, regExp]");
				// if dieOnError is true, stop program and print error to screen.
				if ($err->dieOnError == true) {
					$err->printErrors();
					die();
				}
			}
		}
		if(count($this->vars) > 0) {
			$keys = array_keys($this->vars);
			echo "<TABLE bgcolor=\"#3D2648\" cellpadding=\"0\" cellspacing=\"0\" border=\"0\" width=\"600\">";
				echo "<TR>";
					echo "<TD>";
						echo "<TABLE cellpadding=\"4\" cellspacing=\"1\" border=\"0\">";
							echo "<TR>";
								echo "<TH bgcolor=\"#9162AC\" width=\"600\" colspan=\"9\" align=\"left\">";
									echo "<FONT face=\"arial, verdana\" size=\"1\" color=\"yellow\"><B>List of variables registered in class: </B></FONT>";
									echo "<FONT face=\"arial, verdana\" size=\"1\" color=\"white\"><B>". get_class($this) ."</B></FONT>";
								echo "</TH>";
						echo "</TR>";
						echo "<TR>";
						if (func_num_args() == 1) {
								echo "<TH bgcolor=\"#9162AC\" width=\"100\"><FONT face=\"arial, verdana\" size=\"1\" color=\"white\"><B>Variable name</B></FONT></TH>";
								echo "<TH bgcolor=\"#9162AC\" width=\"50\"><FONT face=\"arial, verdana\" size=\"1\" color=\"white\"><B>". $params[0] ."</B></FONT></TH>";
						}
						else {
								echo "<TH bgcolor=\"#9162AC\" width=\"100\"><FONT face=\"arial, verdana\" size=\"1\" color=\"white\"><B>Variable name</B></FONT></TH>";
								echo "<TH bgcolor=\"#9162AC\" width=\"50\"><FONT face=\"arial, verdana\" size=\"1\" color=\"white\"><B>alias</B></FONT></TH>";
								echo "<TH bgcolor=\"#9162AC\" width=\"200\"><FONT face=\"arial, verdana\" size=\"1\" color=\"white\"><B>Value</B></FONT></TH>";
								echo "<TH bgcolor=\"#9162AC\" width=\"50\"><FONT face=\"arial, verdana\" size=\"1\" color=\"white\"><B>autoHTTP</B></FONT></TH>";
								echo "<TH bgcolor=\"#9162AC\" width=\"50\"><FONT face=\"arial, verdana\" size=\"1\" color=\"white\"><B>autoSQL</B></FONT></TH>";
								echo "<TH bgcolor=\"#9162AC\" width=\"50\"><FONT face=\"arial, verdana\" size=\"1\" color=\"white\"><B>autoTPL</B></FONT></TH>";
								echo "<TH bgcolor=\"#9162AC\" width=\"50\"><FONT face=\"arial, verdana\" size=\"1\" color=\"white\"><B>Template</B></FONT></TH>";
								echo "<TH bgcolor=\"#9162AC\" width=\"200\"><FONT face=\"arial, verdana\" size=\"1\" color=\"white\"><B>Regular expression</B></FONT></TH>";
								echo "<TH bgcolor=\"#9162AC\" width=\"200\"><FONT face=\"arial, verdana\" size=\"1\" color=\"white\"><B>Form Error</B></FONT></TH>";
						}
						echo "</TR>";
						for($i=0; $i < count($keys); $i++) {
							$this->vars[$keys[$i]]["autoHTTP"] > 0 ? $autoHTTP = "true" : $autoHTTP = "false";
							$this->vars[$keys[$i]]["autoSQL"] > 0 ? $autoSQL = "true" : $autoSQL = "false";
							$this->vars[$keys[$i]]["autoTPL"] > 0 ? $autoTPL = "true" : $autoTPL = "false";
							$this->vars[$keys[$i]]["formError"] > 0 ? $formError = "true" : $formError = "false";
							echo "<TR>";
								if (func_num_args() == 1) {
									echo "<TD bgcolor=\"#9162AC\" width=\"200\"><FONT face=\"arial, verdana\" size=\"2\"><B>" . $keys[$i] . "&nbsp;</B></FONT></TD>";
									if ($params[0] == "autoHTTP") {
										echo "<TD bgcolor=\"#C6ADD3\" width=\"400\"><FONT face=\"arial, verdana\" size=\"2\">" . $autoHTTP . "&nbsp;</FONT></TD>";
									}
									else if ($params[0] == "autoSQL") {
										echo "<TD bgcolor=\"#C6ADD3\" width=\"400\"><FONT face=\"arial, verdana\" size=\"2\">" . $autoSQL . "&nbsp;</FONT></TD>";
									}
									else if ($params[0] == "formError") {
										echo "<TD bgcolor=\"#C6ADD3\" width=\"400\"><FONT face=\"arial, verdana\" size=\"2\">" . $formError . "&nbsp;</FONT></TD>";
									}
									else if ($params[0] == "value") {
										echo "<TD bgcolor=\"#C6ADD3\" width=\"400\"><FONT face=\"arial, verdana\" size=\"2\">" . $this->$keys[$i] . "&nbsp;</FONT></TD>";
									}
									else {
										echo "<TD bgcolor=\"#C6ADD3\" width=\"400\"><FONT face=\"arial, verdana\" size=\"2\">" . $this->vars[$keys[$i]][$params[0]] . "&nbsp;</FONT></TD>";
									}
								}
								else {
									echo "<TD bgcolor=\"#9162AC\" width=\"100\"><FONT face=\"arial, verdana\" size=\"2\"><B>" . $keys[$i] . "&nbsp;</B></FONT></TD>";
									echo "<TD bgcolor=\"#C6ADD3\" width=\"50\"><FONT face=\"arial, verdana\" size=\"2\">" . $this->vars[$keys[$i]]["alias"] . "&nbsp;</FONT></TD>";
									echo "<TD bgcolor=\"#C6ADD3\" width=\"200\"><FONT face=\"arial, verdana\" size=\"2\">" . $this->$keys[$i] . "&nbsp;</FONT></TD>";
									echo "<TD bgcolor=\"#C6ADD3\" width=\"50\"><FONT face=\"arial, verdana\" size=\"2\">" . $autoHTTP . "&nbsp;</FONT></TD>";
									echo "<TD bgcolor=\"#C6ADD3\" width=\"50\"><FONT face=\"arial, verdana\" size=\"2\">" . $autoSQL . "&nbsp;</FONT></TD>";
									echo "<TD bgcolor=\"#C6ADD3\" width=\"50\"><FONT face=\"arial, verdana\" size=\"2\">" . $autoTPL . "&nbsp;</FONT></TD>";
									echo "<TD bgcolor=\"#C6ADD3\" width=\"50\"><FONT face=\"arial, verdana\" size=\"2\">" . $this->vars[$keys[$i]]["TPL"] . "&nbsp;</FONT></TD>";
									echo "<TD bgcolor=\"#C6ADD3\" width=\"200\"><FONT face=\"arial, verdana\" size=\"2\">" . $this->vars[$keys[$i]]["regExp"] . "&nbsp;</FONT></TD>";
									echo "<TD bgcolor=\"#C6ADD3\" width=\"200\"><FONT face=\"arial, verdana\" size=\"2\">" . $this->vars[$keys[$i]]["formError"] . "&nbsp;</FONT></TD>";
								}
							echo "</TR>";
						}
						echo "</TABLE>";
					echo "</TD>";
				echo "</TR>";
			echo "</TABLE>";
		}
	}

	/*********************************
	* Print all variables registered with this object
	* @param Array $arr
	***/
	function printArray($arr) {
		global $err;

		$tmp_array = $this->$arr;
		$keys = array_keys($tmp_array);

		echo "<TABLE bgcolor=\"#3D2648\" cellpadding=\"0\" cellspacing=\"0\" border=\"0\" width=\"600\">";
			echo "<TR>";
				echo "<TD>";
					echo "<TABLE cellpadding=\"4\" cellspacing=\"1\" border=\"0\">";
						echo "<TR>";
							echo "<TH bgcolor=\"#9162AC\" width=\"600\" colspan=\"2\" align=\"left\">";
								echo "<FONT face=\"arial, verdana\" size=\"1\" color=\"yellow\"><B>Class-name: </B></FONT>";
								echo "<FONT face=\"arial, verdana\" size=\"1\" color=\"white\"><B>". get_class($this) ."&nbsp;&nbsp;&nbsp;&nbsp;</B></FONT>";
								echo "<FONT face=\"arial, verdana\" size=\"1\" color=\"yellow\"><B>Array-name: </B></FONT>";
								echo "<FONT face=\"arial, verdana\" size=\"1\" color=\"white\"><B>". $arr ."</B></FONT>";
							echo "</TH>";
					echo "</TR>";
						echo "<TR>";
							echo "<TH bgcolor=\"#9162AC\" width=\"100\"><FONT face=\"arial, verdana\" size=\"1\" color=\"white\"><B>Array index</B></FONT></TH>";
							echo "<TH bgcolor=\"#9162AC\" width=\"500\"><FONT face=\"arial, verdana\" size=\"1\" color=\"white\"><B>Array element</B></FONT></TH>";
					echo "</TR>";

					for($i=0; $i < count($keys); $i++) {
						echo "<TR>";
							echo "<TD bgcolor=\"#9162AC\" width=\"100\"><FONT face=\"arial, verdana\" size=\"2\"><B>" . $keys[$i] . "&nbsp;</B></FONT></TD>";
								echo "<TD bgcolor=\"#C6ADD3\" width=\"500\"><FONT face=\"arial, verdana\" size=\"2\">" . $tmp_array[$keys[$i]] . "&nbsp;</FONT></TD>";
						echo "</TR>";
					}
					echo "</TABLE>";
				echo "</TD>";
			echo "</TR>";
		echo "</TABLE>";
	}

	function printMethods() {
		$class_methods = get_class_methods(get_class($this));		

		echo "<TABLE bgcolor=\"#3D2648\" cellpadding=\"0\" cellspacing=\"0\" border=\"0\" width=\"600\">";
			echo "<TR>";
				echo "<TD>";
					echo "<TABLE cellpadding=\"4\" cellspacing=\"1\" border=\"0\">";
						echo "<TR>";
							echo "<TH bgcolor=\"#9162AC\" width=\"600\" align=\"left\">";
								echo "<FONT face=\"arial, verdana\" size=\"1\" color=\"yellow\"><B>List of methods in class: </B></FONT>";
								echo "<FONT face=\"arial, verdana\" size=\"1\" color=\"white\"><B>". get_class($this) ."&nbsp;</B></FONT>";
							echo "</TH>";
					echo "</TR>";
						echo "<TR>";
							echo "<TH bgcolor=\"#9162AC\" width=\"500\"><FONT face=\"arial, verdana\" size=\"1\" color=\"white\"><B>Method names</B></FONT></TH>";
					echo "</TR>";

					for($i=0; $i < count($class_methods); $i++) {
						echo "<TR>";
								echo "<TD bgcolor=\"#C6ADD3\" width=\"500\"><FONT face=\"arial, verdana\" size=\"2\">" . $class_methods[$i] . "&nbsp;</FONT></TD>";
						echo "</TR>";
					}
					echo "</TABLE>";
				echo "</TD>";
			echo "</TR>";
		echo "</TABLE>";
		
	}

	function printAll() {

		echo "<BR>";
		echo "<TABLE bgcolor=\"#3D2648\" cellpadding=\"0\" cellspacing=\"2\" border=\"0\">";
			echo "<TR>";
				echo "<TD>";
					echo "<TABLE bgcolor=\"#EEDBED\" cellpadding=\"0\" cellspacing=\"0\" border=\"0\" width=\"600\">\n";
						echo "<TR>\n";
							echo "<TD width=\"20\">&nbsp;</TD>\n";
							echo "<TD colspan=\"2\" height=\"30\"><FONT face=\"arial, verdana\" size=\"3\" color=\"#800000\"><B>Class:<FONT color=\"black\">". get_class($this) ."</FONT></B></FONT><TD>\n";
						echo "</TR>\n";
						echo "<TR>\n";
							echo "<TD width=\"20\">&nbsp;</TD>\n";
							echo "<TD>\n";
							echo "<FONT face=\"arial, verdana\" size=\"2\" color=\"#9162AC\"><B>". get_parent_class($this) ."->". get_class($this) ."->variables</FONT>";
								$this->printVars();
								if(count($this->arrays) > 0) {
									echo "<BR>";
									echo "<FONT face=\"arial, verdana\" size=\"2\" color=\"#9162AC\"><B>". get_parent_class($this) ."->". get_class($this) ."->arrays</FONT>";
									for($i=0; $i < count($this->arrays); $i++) {
										echo "<BR>";
										$this->printArray($this->arrays[$i]);
									}
								}
							echo "</TD>";
							echo "<TD width=\"20\">&nbsp;</TD>\n";
						echo "</TR>";
						echo "<TR>\n";
							echo "<TD colspan=\"3\" height=\"10\">&nbsp;<TD>\n";
						echo "</TR>\n";
					echo "</TABLE>";
				echo "</TD>";
			echo "</TR>";
		echo "</TABLE>";

		if(count($this->objects) > 0) {
			$keys = array_keys($this->objects);
			for($i=0; $i < count($keys); $i++) {
				$this->$keys[$i]->printAll($levels);
			}
		}
	}


	/******************************
	* Returns a string representation of all 
	* parent classes and the current cass
	* @return String object tree
	***/
	function getParent() {
			$obj = $this;
			while(get_parent_class($obj)) {
				$parent = get_parent_class($obj);
				$tree .= $parent ."->";
				$obj = $parent;
			}
		return $tree . get_class($this);
	}

	function display() {
		$this->assignToSmarty($this->smarty, $this->current_TPL);
		$this->smarty->display($this->current_TPL . $this->tpl_prefix);
//		unset($this->smarty->_tpl_vars);
		unset($this->smarty);
	}
}
	
?>